@@ -11,18 +11,20 @@
 #    under the License.
 
 import ddt
-import six
-
 from oslo_log import log as logging
 from oslo_utils import units
+import six
 from tempest import config
+from tempest.lib import decorators
 from tempest.lib import exceptions
 from testtools import testcase as tc
 
 from manila_tempest_tests.common import constants
+from manila_tempest_tests.common import waiters
 from manila_tempest_tests.tests.api import base
 from manila_tempest_tests.tests.scenario import manager_share as manager
 
+
 CONF = config.CONF
 LOG = logging.getLogger(__name__)
 
@@ -45,6 +47,7 @@ class ShareExtendBase(manager.ShareScenarioTest):
      * Terminate the instance
     """
 
+    @decorators.idempotent_id('e1c0d614-c8f2-43cf-9c49-25808b07ba4a')
     @tc.attr(base.TAG_POSITIVE, base.TAG_BACKEND)
     def test_create_extend_and_write(self):
         default_share_size = CONF.share.share_size
@@ -61,7 +64,7 @@ class ShareExtendBase(manager.ShareScenarioTest):
         remote_client = self.init_remote_client(instance)
 
         LOG.debug('Step 4 - grant access')
-        location = self.get_share_export_location_for_mount(share)
+        location = self.get_user_export_locations(share)[0]
         self.allow_access(instance=instance, remote_client=remote_client,
                           locations=location)
 
@@ -93,8 +96,8 @@ class ShareExtendBase(manager.ShareScenarioTest):
         extended_share_size = default_share_size + 1
         self.shares_v2_client.extend_share(share["id"],
                                            new_size=extended_share_size)
-        self.shares_v2_client.wait_for_share_status(share["id"],
-                                                    constants.STATUS_AVAILABLE)
+        waiters.wait_for_resource_status(
+            self.shares_v2_client, share["id"], constants.STATUS_AVAILABLE)
         share = self.shares_v2_client.get_share(share["id"])
         self.assertEqual(extended_share_size, int(share["size"]))
 
@@ -159,6 +162,9 @@ class TestShareExtendNFS(ShareExtendBase):
             instance=kwargs['instance'], access_level=access_level)
 
     def mount_share(self, location, remote_client, target_dir=None):
+
+        self.validate_ping_to_export_location(location, remote_client)
+
         target_dir = target_dir or "/mnt"
         remote_client.exec_command(
             "sudo mount -vt nfs \"%s\" %s" % (location, target_dir)
@@ -181,6 +187,9 @@ class TestShareExtendCIFS(ShareExtendBase):
             instance=kwargs['instance'], access_level=access_level)
 
     def mount_share(self, location, remote_client, target_dir=None):
+
+        self.validate_ping_to_export_location(location, remote_client)
+
         location = location.replace("\\", "/")
         target_dir = target_dir or "/mnt"
         remote_client.exec_command(
@@ -191,12 +200,17 @@ class TestShareExtendCIFS(ShareExtendBase):
 class TestShareExtendCEPHFS(ShareExtendBase, manager.BaseShareCEPHFSTest):
     protocol = "cephfs"
 
+    @decorators.idempotent_id('9ca1e4a9-23e3-4da6-a63e-46e7919335e0')
     @tc.attr(base.TAG_POSITIVE, base.TAG_BACKEND)
     def test_create_extend_and_write_with_ceph_fuse_client(self):
         self.mount_client = 'fuse'
         super(TestShareExtendCEPHFS, self).test_create_extend_and_write()
 
 
+class TestShareExtendNFSIPv6(TestShareExtendNFS):
+    ip_version = 6
+
+
 # NOTE(u_glide): this function is required to exclude ShareExtendBase
 # from executed test cases.
 # See: https://docs.python.org/3/library/unittest.html#load-tests-protocol
