@@ -13,10 +13,11 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-from netaddr import ip
+from collections import OrderedDict
 import random
 import re
 
+from netaddr import ip
 import six
 from tempest import config
 import testtools
@@ -27,6 +28,15 @@ SHARE_REPLICA_QUOTAS_MICROVERSION = "2.53"
 EXPERIMENTAL = {'X-OpenStack-Manila-API-Experimental': 'True'}
 
 
+def deduplicate(items):
+    """De-duplicate a list of items while preserving the order.
+
+    It is useful when passing a list of items to ddt.data, in order
+    to remove duplicated elements which may be specified as constants.
+    """
+    return list(OrderedDict.fromkeys(items))
+
+
 def get_microversion_as_tuple(microversion_str):
     """Transforms string-like microversion to two-value tuple of integers.
 
